@@ -1,5 +1,12 @@
 import json
 
+from enum import Enum
+
+
+class ParsingStyle(Enum):
+    SNAKE_CASE = 1
+    CAMEL_CASE = 1
+
 
 class JSONParsable:
     """
@@ -35,9 +42,22 @@ class JSONParsable:
                 # getattr raised an AttributeError, continue with the next value
                 continue
 
-    def to_dictionary(self):
-        return self.__dict__
+    def to_dictionary(self, style: ParsingStyle) -> dict:
+        if style == ParsingStyle.SNAKE_CASE:
+            return self.__dict__
+        else:
+            dict_value = self.__dict__
+            for key in dict_value.keys:
+                value = dict_value.pop(key)
+                dict_value[self.JSONParsable.to_camel_case(key)] = value
+            return dict_value
 
-    def to_json(self):
-        return json.dumps(self, default=lambda o: o.to_dictionary(),
+
+    def to_json(self, style: ParsingStyle) -> str:
+        return json.dumps(self, default=lambda o: o.to_dictionary(style=style),
                           sort_keys=True, indent=4)
+
+    @classmethod
+    def to_camel_case(cls, snake_case_value: str) -> str:
+        components = snake_case_value.split('_')
+        return components[0] + ''.join(x.title() for x in components[1:])
